Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the agents v1alpha1 API group. +kubebuilder:object:generate=true +groupName=ate.dev
Index ¶
- Variables
- func Resource(resource string) schema.GroupResource
- type ActorTemplate
- type ActorTemplateList
- type ActorTemplateSpec
- type ActorTemplateStatus
- type AuthenticationConfig
- type Container
- type GCPAuthenticationConfig
- type PhaseType
- type RunscConfig
- type RunscPlatformConfig
- type SnapshotsConfig
- type WorkerPool
- type WorkerPoolList
- type WorkerPoolSpec
- type WorkerPoolStatus
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects. GroupVersion = schema.GroupVersion{Group: "ate.dev", Version: "v1alpha1"} // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = GroupVersion // SchemeBuilder is used to add go types to the GroupVersionKind scheme. SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type ActorTemplate ¶
type ActorTemplate struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// spec defines the desired state of ActorTemplate
// +required
Spec ActorTemplateSpec `json:"spec"`
// status is the observed state of ActorTemplate
// +optional
Status ActorTemplateStatus `json:"status,omitempty"`
}
+genclient +kubebuilder:object:generate=true +kubebuilder:object:root=true +kubebuilder:resource:scope=Namespaced,shortName=actortemplate +kubebuilder:subresource:status
func (*ActorTemplate) DeepCopy ¶
func (in *ActorTemplate) DeepCopy() *ActorTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActorTemplate.
func (*ActorTemplate) DeepCopyInto ¶
func (in *ActorTemplate) DeepCopyInto(out *ActorTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ActorTemplate) DeepCopyObject ¶
func (in *ActorTemplate) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ActorTemplateList ¶
type ActorTemplateList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ActorTemplate `json:"items"`
}
ActorTemplateList contains a list of ActorTemplates. +kubebuilder:object:generate=true +kubebuilder:object:root=true +kubebuilder:resource:scope=Namespaced,shortName=actortemplate
func (*ActorTemplateList) DeepCopy ¶
func (in *ActorTemplateList) DeepCopy() *ActorTemplateList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActorTemplateList.
func (*ActorTemplateList) DeepCopyInto ¶
func (in *ActorTemplateList) DeepCopyInto(out *ActorTemplateList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ActorTemplateList) DeepCopyObject ¶
func (in *ActorTemplateList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ActorTemplateSpec ¶
type ActorTemplateSpec struct {
// PauseImage is the container to use as the root sandbox container.
//
// Typically, set it to [1] for on-gcp, and [2] for off-gcp
//
// - [1] gcr.io/gke-release/pause@sha256:bcbd57ba5653580ec647b16d8163cdd1112df3609129b01f912a8032e48265da
// - [2] registry.k8s.io/pause:3.10.2@sha256:f548e0e8e3dc1896ca956272154dde3314e8cc4fde0a57577ee9fa1c63f5baf4
//
// +required
PauseImage string `json:"pauseImage,omitempty"`
// Containers is the workload definition.
//
// +optional
Containers []Container `json:"containers,omitempty"`
// Snapshots configuration for the actor.
// +required
SnapshotsConfig SnapshotsConfig `json:"snapshotsConfig"`
// Name of the worker pool to use for the actor.
// +required
WorkerPoolRef corev1.ObjectReference `json:"workerPoolRef"`
// Parameters for fetching the runsc binary to use.
//
// +required
Runsc RunscConfig `json:"runsc,omitempty"`
}
ActorTemplateSpec defined desired spec of an actor.
func (*ActorTemplateSpec) DeepCopy ¶
func (in *ActorTemplateSpec) DeepCopy() *ActorTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActorTemplateSpec.
func (*ActorTemplateSpec) DeepCopyInto ¶
func (in *ActorTemplateSpec) DeepCopyInto(out *ActorTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ActorTemplateStatus ¶
type ActorTemplateStatus struct {
// Phase of the actor template.
// +optional
Phase PhaseType `json:"phase,omitempty"`
GoldenActorID string `json:"goldenActorID,omitempty"`
TakeGoldenSnapshotAt metav1.Time `json:"takeGoldenSnapshotAt,omitempty"`
GoldenSnapshot string `json:"goldenSnapshot,omitempty"`
// conditions defines the status conditions array
// +optional
Conditions []metav1.Condition `json:"conditions,omitempty"`
}
func (*ActorTemplateStatus) DeepCopy ¶
func (in *ActorTemplateStatus) DeepCopy() *ActorTemplateStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActorTemplateStatus.
func (*ActorTemplateStatus) DeepCopyInto ¶
func (in *ActorTemplateStatus) DeepCopyInto(out *ActorTemplateStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AuthenticationConfig ¶
type AuthenticationConfig struct {
// Use GCP application-default credentials.
GCP *GCPAuthenticationConfig `json:"gcp,omitempty"`
}
Authentication configuration for atelet to download static files.
If no members are set, then atelet will use anonymous authentication.
func (*AuthenticationConfig) DeepCopy ¶
func (in *AuthenticationConfig) DeepCopy() *AuthenticationConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AuthenticationConfig.
func (*AuthenticationConfig) DeepCopyInto ¶
func (in *AuthenticationConfig) DeepCopyInto(out *AuthenticationConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Container ¶
type Container struct {
// Name of the container.
// +required
Name string `json:"name"`
// Image to use for the worker replicas.
Image string `json:"image,omitempty"`
// Entrypoint array. Not executed within a shell.
// +optional
// +listType=atomic
Command []string `json:"command,omitempty"`
// List of ports to expose from the container.
Ports []corev1.ContainerPort `json:"ports,omitempty"`
// Environment variables to set in the worker replicas.
Env []corev1.EnvVar `json:"env,omitempty"`
}
A single application container that you want to run within a WorkerPool.
func (*Container) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Container.
func (*Container) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GCPAuthenticationConfig ¶
type GCPAuthenticationConfig struct {
}
func (*GCPAuthenticationConfig) DeepCopy ¶
func (in *GCPAuthenticationConfig) DeepCopy() *GCPAuthenticationConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GCPAuthenticationConfig.
func (*GCPAuthenticationConfig) DeepCopyInto ¶
func (in *GCPAuthenticationConfig) DeepCopyInto(out *GCPAuthenticationConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RunscConfig ¶
type RunscConfig struct {
// Configuration for the amd64 binary.
//
// +optional
AMD64 *RunscPlatformConfig `json:"amd64,omitempty"`
// Configuration for the arm64 binary.
//
// +optional
ARM64 *RunscPlatformConfig `json:"arm64,omitempty"`
// How should atelet authenticate to download the runsc binary?
Authentication AuthenticationConfig `json:"authentication,omitempty"`
}
func (*RunscConfig) DeepCopy ¶
func (in *RunscConfig) DeepCopy() *RunscConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RunscConfig.
func (*RunscConfig) DeepCopyInto ¶
func (in *RunscConfig) DeepCopyInto(out *RunscConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RunscPlatformConfig ¶
type RunscPlatformConfig struct {
// The SHA256 hash of the binary to download. Used both to name the
// downloaded file (for preventing conflicts), and to check the integrity of
// the downloaded file.
//
// +required
SHA256Hash string `json:"sha256Hash,omitempty"`
// A gs:// URL pointing to a runsc binary that can be downloaded (possibly
// with atelet's credentials).
//
// +required
URL string `json:"url,omitempty"`
}
func (*RunscPlatformConfig) DeepCopy ¶
func (in *RunscPlatformConfig) DeepCopy() *RunscPlatformConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RunscPlatformConfig.
func (*RunscPlatformConfig) DeepCopyInto ¶
func (in *RunscPlatformConfig) DeepCopyInto(out *RunscPlatformConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SnapshotsConfig ¶
type SnapshotsConfig struct {
// Location to store snapshots in.
// +required
Location string `json:"location"`
}
func (*SnapshotsConfig) DeepCopy ¶
func (in *SnapshotsConfig) DeepCopy() *SnapshotsConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SnapshotsConfig.
func (*SnapshotsConfig) DeepCopyInto ¶
func (in *SnapshotsConfig) DeepCopyInto(out *SnapshotsConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkerPool ¶
type WorkerPool struct {
metav1.TypeMeta `json:",inline"`
// metadata is a standard object metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// spec defines the desired state of WorkerPool
// +required
Spec WorkerPoolSpec `json:"spec"`
// status is the observed state of WorkerPool
// +optional
Status WorkerPoolStatus `json:"status,omitempty"`
}
WorkerPool is the Schema for the workerpools API +genclient +kubebuilder:object:generate=true +kubebuilder:object:root=true +kubebuilder:resource:scope=Namespaced,shortName=workerpool +kubebuilder:subresource:status
func (*WorkerPool) DeepCopy ¶
func (in *WorkerPool) DeepCopy() *WorkerPool
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerPool.
func (*WorkerPool) DeepCopyInto ¶
func (in *WorkerPool) DeepCopyInto(out *WorkerPool)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WorkerPool) DeepCopyObject ¶
func (in *WorkerPool) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type WorkerPoolList ¶
type WorkerPoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []WorkerPool `json:"items"`
}
WorkerPoolList contains a list of WorkerPools. +kubebuilder:object:generate=true +kubebuilder:object:root=true
func (*WorkerPoolList) DeepCopy ¶
func (in *WorkerPoolList) DeepCopy() *WorkerPoolList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerPoolList.
func (*WorkerPoolList) DeepCopyInto ¶
func (in *WorkerPoolList) DeepCopyInto(out *WorkerPoolList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WorkerPoolList) DeepCopyObject ¶
func (in *WorkerPoolList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type WorkerPoolSpec ¶
type WorkerPoolSpec struct {
// Replicas is the number of worker pods to run.
// +required
Replicas int32 `json:"replicas"`
// AteomImage is the ateom container image to deploy as workers.
// +required
AteomImage string `json:"ateomImage"`
}
func (*WorkerPoolSpec) DeepCopy ¶
func (in *WorkerPoolSpec) DeepCopy() *WorkerPoolSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerPoolSpec.
func (*WorkerPoolSpec) DeepCopyInto ¶
func (in *WorkerPoolSpec) DeepCopyInto(out *WorkerPoolSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkerPoolStatus ¶
type WorkerPoolStatus struct {
}
func (*WorkerPoolStatus) DeepCopy ¶
func (in *WorkerPoolStatus) DeepCopy() *WorkerPoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerPoolStatus.
func (*WorkerPoolStatus) DeepCopyInto ¶
func (in *WorkerPoolStatus) DeepCopyInto(out *WorkerPoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.