Documentation
¶
Overview ¶
Package credbundle handles credential bundle files written by Kubernetes Pod Certificates.
A credential bundle is a single file with multiple PEM entries. The first entry is a PRIVATE KEY block, and all remaining entries are CERTIFICATE blocks. The CERTIFICATE blocks are in leaf-to-root order, and may or may not include the root.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Loader ¶
func Loader(path string) func(*tls.ClientHelloInfo) (*tls.Certificate, error)
Loader reads a private key and certificate chain from a credential bundle file as written by the Kubernetes Pod Certificates mechanism.
Returns a function that can be used as GetCertificate in a tls.Config
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.